=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2006-06-07 16:49:20 +0000
+++ bzrlib/commit.py	2006-06-07 18:12:52 +0000
@@ -82,7 +82,6 @@
                            ConflictsInTree,
                            StrictCommitFailed
                            )
-from bzrlib.revision import Revision
 from bzrlib.testament import Testament
 from bzrlib.trace import mutter, note, warning
 from bzrlib.xml5 import serializer_v5
@@ -307,11 +306,10 @@
                 raise PointlessCommit()
 
             self._emit_progress_update()
-            self.inv_sha1 = self.builder.finish_inventory()
+            self.builder.finish_inventory()
             self._emit_progress_update()
             self.builder.set_message(self.message)
-            self._make_revision()
-            self.rev_id = self.builder._new_revision_id
+            self.rev_id = self.builder.commit()
             # revision data is in the local branch now.
             
             # upload revision data to the master.
@@ -473,19 +471,6 @@
                 else:
                     mutter("commit will ghost revision %r", parent_id)
             
-    def _make_revision(self):
-        """Record a new revision object for this commit."""
-        rev = Revision(timestamp=self.builder._timestamp,
-                       timezone=self.builder._timezone,
-                       committer=self.builder._committer,
-                       message=self.builder.message,
-                       inventory_sha1=self.inv_sha1,
-                       revision_id=self.builder._new_revision_id,
-                       properties=self.builder._revprops)
-        rev.parent_ids = self.builder.parents
-        self.branch.repository.add_revision(self.builder._new_revision_id, rev, 
-            self.builder.new_inventory, self.builder._config)
-
     def _remove_deleted(self):
         """Remove deleted files from the working inventories.
 

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2006-06-07 16:49:20 +0000
+++ bzrlib/repository.py	2006-06-07 18:12:52 +0000
@@ -34,7 +34,7 @@
 from bzrlib.lockdir import LockDir
 from bzrlib.osutils import (safe_unicode, rand_bytes, compact_date, 
                             local_time_offset)
-from bzrlib.revision import NULL_REVISION
+from bzrlib.revision import NULL_REVISION, Revision
 from bzrlib.store.versioned import VersionedFileStore, WeaveStore
 from bzrlib.store.text import TextStore
 from bzrlib.symbol_versioning import *
@@ -1918,13 +1918,28 @@
 
         self._generate_revision_if_needed()
 
+    def commit(self):
+        """Make the actual commit.
+
+        :return: The revision id of the recorded revision.
+        """
+        rev = Revision(timestamp=self._timestamp,
+                       timezone=self._timezone,
+                       committer=self._committer,
+                       message=self.message,
+                       inventory_sha1=self.inv_sha1,
+                       revision_id=self._new_revision_id,
+                       properties=self._revprops)
+        rev.parent_ids = self.parents
+        self.repository.add_revision(self._new_revision_id, rev, 
+            self.new_inventory, self._config)
+        return self._new_revision_id
+
     def finish_inventory(self):
         """Tell the builder that the inventory is finished.
-        
-        :return: SHA1 of the encoded inventory.
         """
         self.new_inventory.revision = self._new_revision_id
-        return self.repository.add_inventory(
+        self.inv_sha1 = self.repository.add_inventory(
             self._new_revision_id,
             self.new_inventory,
             self.parents

=== modified file 'bzrlib/tests/repository_implementations/test_commit_builder.py'
--- bzrlib/tests/repository_implementations/test_commit_builder.py	2006-06-07 16:49:20 +0000
+++ bzrlib/tests/repository_implementations/test_commit_builder.py	2006-06-07 18:12:52 +0000
@@ -30,9 +30,17 @@
     def testFinishInventory(self):
         tree = self.make_branch_and_tree(".")
         builder = tree.branch.get_commit_builder([])
-        self.assertIsInstance(builder.finish_inventory(), basestring)
+        builder.finish_inventory()
 
     def testSetMessage(self):
         tree = self.make_branch_and_tree(".")
         builder = tree.branch.get_commit_builder([], revision_id="foo")
         builder.set_message("foobar")
+
+    def testCommit(self):
+        tree = self.make_branch_and_tree(".")
+        builder = tree.branch.get_commit_builder([], revision_id="foo")
+        builder.finish_inventory()
+        builder.set_message('foo')
+        builder.commit()
+        self.assertTrue(tree.branch.repository.has_revision("foo"))

